@@ -4,7 +4,7 @@ use Moo;
 use Example::Syntax;
 use Example::View::HTML
   -tags => qw(div a fieldset legend br form_for script),
-  -util => qw(path user),
+  -util => qw(user),
 
 has 'account' => ( is=>'ro', required=>1 );
 
@@ -16,8 +16,7 @@ sub render($self, $c) {
   my $employment_options = user->employment_options;
   my @status_options = $self->account->profile->status_list;
 
-
-  return form_for 'account', +{action=>path('update'), data=>{remote=>'true', method=>'patch'}}, sub ($self, $fb, $account) {
+  return form_for 'account', +{data=>{remote=>'true', method=>'patch'}}, sub ($self, $fb, $account) {
     div +{ if=>$fb->successfully_updated, class=>'alert alert-success', role=>'alert' }, 'Successfully Updated',
     fieldset [
       $fb->legend,
