@@ -3,14 +3,15 @@ package Example::View::HTML::Navbar;
 use Moo;
 use Example::Syntax;
 use Example::View::HTML
-  -tags => qw(nav a div button span);
+  -tags => qw(nav a div button span),
+  -utils => qw(path user);
 
 has active_link => (is=>'ro', required=>1);
 
 sub navlinks ($self) {
   state @links = (
     +{ href => $self->path('/home/user_show'), data => {title=>'Home', key=>'home'} },
-    +{ href => $self->path('/account/edit'), data => {title=>'Account Details', key=>'account_details'} },
+    +{ href => $self->path('/account/edit', [user->id]), data => {title=>'Account Details', key=>'account_details'} },
     +{ href => $self->path('/todos/list'), data => {title=>'Todo List', key=>'todo_list'} },
     +{ href => $self->path('/contacts/list'), data => {title=>'Contact List', key=>'contact_list'} },
     +{ href => $self->path('/posts/list'), data => {title=>'My Posts', key=>'my_posts'} }, 
