@@ -4,15 +4,15 @@ use Moo;
 use Example::Syntax;
 use Example::View::HTML
   -tags => qw(fieldset form_for input legend div a link_to),
-  -helpers => qw(path),
+  -helpers => qw(register_build_uri),
   -views => 'HTML::Page';
 
-has 'user' => (is=>'ro', required=>1);
+has 'person' => (is=>'ro', required=>1);
 
 sub render($self, $c) {
   html_page page_title => 'Sign In', sub($page) {
     div +{ class=>'col-5 mx-auto' },
-      form_for $self->user, +{action=>path('/session/create')}, sub ($self, $fb, $u) {
+      form_for 'person', sub ($self, $fb, $person) {
         fieldset [
           legend 'Sign In',
           div +{ class=>'form-group' },
@@ -28,9 +28,9 @@ sub render($self, $c) {
           $fb->submit('Sign In'),
         ],
         div +{ class=>'text-center' },
-          link_to path('/register/build'), 'Register', 
+          link_to register_build_uri, 'Register', 
       };
-    };
+  };
 }
  
 1;
