@@ -4,7 +4,7 @@ use Moo;
 use Example::Syntax;
 use Example::View::HTML
   -tags => qw(div fieldset a b u span form_for table thead tbody tfoot trow th td),
-  -util => qw($sf path ),
+  -util => qw($sf create_uri edit_uri list_uri),
   -views => 'HTML::Page', 'HTML::Navbar';
 
 has 'list' => (is=>'rw', required=>1, handles=>[qw/pager status/]);
@@ -20,7 +20,7 @@ sub render($self, $c) {
   html_page page_title=>'Todo List', sub($layout) {
     html_navbar active_link=>'todo_list',
     div +{ class=>'col-5 mx-auto' },
-    form_for 'todo', +{action=>path('create')}, sub ($self, $fb, $todo) {
+    form_for 'todo', +{action=>create_uri}, sub ($self, $fb, $todo) {
       fieldset [
         $fb->legend,
         $fb->model_errors({show_message_on_field_errors=>'Please fix the listed errors.'}),
@@ -52,7 +52,7 @@ sub render($self, $c) {
 sub rows :Renders  {
   my ($self, $todo, $i) = @_;
   trow [
-   td a +{ href=>path('edit', [$todo->id]) }, $todo->title,
+   td a +{ href=>edit_uri([$todo]) }, $todo->title,
    td $todo->status,
   ],
 }
@@ -74,7 +74,7 @@ sub page_window_info :Renders ($self) {
 sub pagelist($self) {
   my @page_html = ();
   foreach my $page (1..$self->pager->last_page) {
-    push @page_html, a {href=>path('list', +{'todo.page'=>$page, 'todo.status'=>$self->status}), style=>'margin: .5rem'}, $page == $self->pager->current_page ? b u $page : $page;
+    push @page_html, a {href=>list_uri(+{'todo.page'=>$page, 'todo.status'=>$self->status}), style=>'margin: .5rem'}, $page == $self->pager->current_page ? b u $page : $page;
   }
   return @page_html;
 }
@@ -87,7 +87,7 @@ sub status_filter_box($self) {
 
 sub status_filter($self, $status) {
   return span {style=>'margin: .5rem'}, [b u $status] if $self->status eq $status;
-  return a { href=>path('list', +{'todo.page'=>1, 'todo.status'=>$status}), style=>'margin: .5rem'}, $status;
+  return a { href=>list_uri(+{'todo.page'=>1, 'todo.status'=>$status}), style=>'margin: .5rem'}, $status;
 }
 
 1;
