@@ -1,7 +1,7 @@
 package View::Example::View;
 
 use Moo;
-use Catalyst::View::Valiant
+use Catalyst::View::Valiant::HTMLBuilder
   -tags => qw(blockquote label_tag);
 
 sub stuff2 {
@@ -18,4 +18,4 @@ sub stuff3 :Renders {
   shift->div('stuff333')
 }
 
-1;
\ No newline at end of file
+1;
